/*
 * Copyright (c) 2010, 2014 TradertoolsFX
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:

 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
#property copyright "Copyright (c) 2010, 2014 TradertoolsFX"
#property link 	    "http://www.tradertools-fx.com"
#property description "This content is released under the terms of the MIT license (http://opensource.org/licenses/mit-license.html)."
#property indicator_chart_window

#define GAP_DOWN 0
#define GAP_UP 1

// User parameters
extern string Font = "Times New Roman";
extern int    FontSize = 14;
extern color  HeaderColor = Yellow;
extern color  TextColor = Red;

const string OBJ_PREFIX = "GapInfo_";
int obj_count;

int init()
{
    // Nothing to do
    return(0);
}

int deinit()
{
    for (int i = 0; i < obj_count; i++) {
        ObjectDelete(StringConcatenate(OBJ_PREFIX, i));
    }

    return(0);
}

int start()
{
    // LAST week's close price
    double weekly_close_price = iClose(NULL, PERIOD_W1, 1);
    // THIS week's open price
    double weekly_open_price = iOpen(NULL, PERIOD_W1, 0);
    double gap_in_pips = (weekly_open_price - weekly_close_price) / Point;
    double spread_in_pips = MarketInfo(Symbol(), MODE_SPREAD);
    // Adjust gap and spread for 5 digit pricing
    if (Digits == 3 || Digits == 5) {
        gap_in_pips /= 10;
        spread_in_pips /= 10;
    }

    int gap_direction = -1;
    if (gap_in_pips > 0) {
        gap_direction = GAP_UP;
    } else if (gap_in_pips < 0) {
        gap_direction = GAP_DOWN;
    }

    gap_in_pips = MathAbs(gap_in_pips);
    double net_gap_pips = gap_in_pips - spread_in_pips;

    string label_text[5];
    label_text[0] = "Weekly Gap Stats";
    label_text[1] = StringConcatenate("GAP: ", DoubleToStr(gap_in_pips, 1));
    label_text[2] = StringConcatenate("SPREAD: ", DoubleToStr(spread_in_pips, 1));
    label_text[3] = StringConcatenate("NET GAP: ", DoubleToStr(net_gap_pips, 1));
    label_text[4] = "DIRECTION: ";
    label_text[4] += (gap_direction == GAP_UP) ? "Up" : "Down";

    obj_count = ArraySize(label_text);
    string obj_name;
    color obj_color;
    // Initial coordinates for the text labels
    int x=10, y=20;

    for (int i = 0; i < obj_count; i++) {
        obj_name = StringConcatenate(OBJ_PREFIX, i);
        obj_color = (i == 0) ? HeaderColor : TextColor;

        ObjectCreate(obj_name, OBJ_LABEL, 0, 0, 0);
        ObjectSet(obj_name, OBJPROP_CORNER, 0);
        ObjectSet(obj_name, OBJPROP_XDISTANCE, x);
        ObjectSet(obj_name, OBJPROP_YDISTANCE, y);
        ObjectSetText(obj_name, label_text[i], FontSize, Font, obj_color);

        y += 20;
    }

    return(0);
}
